"=====================================================================
" cream-statusline.vim
"
" Cream -- An easy-to-use configuration of the famous Vim text editor
" [ http://cream.sourceforge.net ] Copyright (C) 2002-2003  Steve Hall
" 
" License:
" This program is free software; you can redistribute it and/or modify
" it under the terms of the GNU General Public License as published by
" the Free Software Foundation; either version 2 of the License, or
" (at your option) any later version.
" [ http://www.gnu.org/licenses/gpl.html ]
" 
" This program is distributed in the hope that it will be useful, but
" WITHOUT ANY WARRANTY; without even the implied warranty of
" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
" General Public License for more details.
" 
" You should have received a copy of the GNU General Public License
" along with this program; if not, write to the Free Software
" Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
" 02111-1307, USA.
"
" Description:
" * Note that statusline colors are dependent on external colors file for User
"   highlight groups.
" * Load status line late so it can react to variable initialization

" show status line for all buffers
set laststatus=2

function! Cream_statusline_path()
	let path = expand('%:p:h')
	" add trailing slash if doesn't exist (note, Windows root
	" drive have this by default, while others do not)
	if strpart(path, strlen(path) - 1) != '/'
		let path = path . '/'
	endif
	if has("win32") && !has("win32unix")
		let path = substitute(path, '/', '\', 'g')
	endif
	return path
endfunction

" File state conditions
function! Cream_statusline_filestate()
	let state = ""

	" indicate file state
	if &modified
		" modified
		return "+"
	else
		" unmodified
		" filename
		let myfile = expand("%:p")
		" writable
		if filewritable(myfile) == 0
			return "-"
		" readonly
		elseif &buftype == "nowrite"
			return "-"
		" help file
		elseif &buftype == "help"
			return "H"
		" normal
		else
			return " "
		endif
	endif
endfunction

" return fileformat (three characters only)
function! Cream_statusline_fileformat()
	if &fileformat == ""
		return "---"
	else
		return &fileformat
	endif
		
endfunction

" return fileencoding (three characters only)
function! Cream_statusline_fileencoding()
	if &fileencoding == ""
		return &encoding
	else
		return &fileencoding
	endif
endfunction

" return file type
function! Cream_statusline_filetype()
	if &filetype == ""
		return "---"
	else
		return &filetype
	endif
endfunction

" indicate expert mode
function! Cream_statusline_expert()
	if exists("g:CREAM_EXPERTMODE")
		if g:CREAM_EXPERTMODE == 1
			return "\ expert"
		endif
	endif
	" expert is off or uninitialized
	return ""
endfunction
" no OFF half needed because not shown

" indicate show invisibles
function! Cream_statusline_showON()
	if &list
		if     &encoding == "latin1"
			"return ""
			return nr2char(182)
		elseif &encoding == "utf-8"
		\ && v:version >= 601
		\ && has("patch469")
			" decimal 182
			return nr2char(182)
		else
			return "$"
		endif
	else
		return ""
	endif
endfunction
function! Cream_statusline_showOFF()
	if &list
		return ""
	else
		if &encoding == "latin1"
			"return ""
			return nr2char(182)
		elseif &encoding == "utf-8"
		\ && v:version >= 601
		\ && has("patch469")
			" decimal 182
			return nr2char(182)
		else
			return "$"
		endif
	endif
endfunction

" indicate wrap
function! Cream_statusline_wrapON()
	if exists("g:CREAM_WRAP")
		if g:CREAM_WRAP == 1
			return "wrap"
		endif
	endif
	" wrap is on
	return ""
endfunction
function! Cream_statusline_wrapOFF()
	if exists("g:CREAM_WRAP")
		if g:CREAM_WRAP != 1
			return "wrap"
		endif
	endif
	" wrap is on
	return ""
endfunction

" indicate autowrap
function! Cream_statusline_autowrapON()
	if exists("g:CREAM_AUTOWRAP")
		if g:CREAM_AUTOWRAP == 1
			" let's just use the number
			return "auto"
		endif
	endif
	" wrap is off or uninitialized
	return ""
endfunction
function! Cream_statusline_autowrapOFF()
	if exists("g:CREAM_AUTOWRAP")
		if g:CREAM_AUTOWRAP != 1
			return "auto"
		endif
	endif
	" wrap is on or uninitialized
	return ""
endfunction

" OBSOLETE
"" return (3 digit) autowidth setting
"" * g:CREAM_AUTOWRAP (1 == on, 0 == off)
"function! Cream_statusline_autowrap_widthON()
"    if exists("g:CREAM_AUTOWRAP")
"        if g:CREAM_AUTOWRAP == 1
"            if exists("g:CREAM_AUTOWRAP_WIDTH")
"                if g:CREAM_AUTOWRAP_WIDTH < 1000
"                    " let's skip the equal mark
"                    let myreturn = g:CREAM_AUTOWRAP_WIDTH
"                    "while strlen(myreturn) < 4
"                    "    let myreturn = ' ' . myreturn
"                    "endwhile
"                    return myreturn
"                else
"                    return 'max'
"                endif
"            endif
"        else
"                " CREAM_AUTOWRAP width unset yet by user (show in "off" colors)
"                return ""
"            endif
"        else
"            return ""
"        endif
"    else
"        " error
"    endif
"endfunction
"function! Cream_statusline_autowrap_widthOFF()
"    if exists("g:CREAM_AUTOWRAP")
"        if g:CREAM_AUTOWRAP == 0
"            if exists("g:CREAM_AUTOWRAP_WIDTH")
"                if g:CREAM_AUTOWRAP_WIDTH < 1000
"                    let myreturn = g:CREAM_AUTOWRAP_WIDTH
"                    "while strlen(myreturn) < 4
"                    "    let myreturn = ' ' . myreturn
"                    "endwhile
"                    return myreturn
"                else
"                    " let's skip the equal mark
"                    return 'max'
"                endif
"            else
"                " CREAM_AUTOWRAP width unset yet by user (show in "off" colors)
"                return ""
"            endif
"        else
"            return ""
"        endif
"    else
"        " error
"    endif
"endfunction

function! Cream_statusline_wrap_width()
" return wrap width setting
    " (don't check existance of g:CREAM_AUTOWRAP)
    if exists("g:CREAM_AUTOWRAP_WIDTH")
        return g:CREAM_AUTOWRAP_WIDTH
    endif
endfunction

function! Cream_statusline_wrap_justifyON()
" return justification mode if not "left"
	if !exists("g:cream_justify")
		return ""
	endif
	if     g:cream_justify == "center"
		return "cntr"
	elseif g:cream_justify == "right"
		return "rght"
	elseif g:cream_justify == "full"
		return "full"
	else
		return ""
	endif
endfunction
function! Cream_statusline_wrap_justifyOFF()
" return justification mode if not "left"
	if !exists("g:cream_justify")
		return "left"
	endif
	if     g:cream_justify == "left"
		return "left"
	else
		return ""
	endif
endfunction

" indicate autoindent
function! Cream_statusline_autoindentON()
	if exists("g:CREAM_AUTOINDENT")
		if g:CREAM_AUTOINDENT == "1"
			return "indt"
		else
			return ""
		endif
	else
		" wrap is on if never initialized
		return "wrap"
	endif
endfunction
function! Cream_statusline_autoindentOFF()
	if exists("g:CREAM_AUTOINDENT")
		if g:CREAM_AUTOINDENT == "1"
			return ""
		else
			return "indt"
		endif
	else
		" autoindent is on if never initialized
		return ""
	endif
endfunction

" indicate mode (Insert/Visual/Select/Replace v. "dangerous" ones ;)
" ( see :help mode() for return strings)
function! Cream_statusline_modeNO()
	let mymode = mode()
	if mymode ==? "i"
		return ""
	elseif mymode ==? "v"
		return ""
	elseif mymode ==? "s"
		return ""
	elseif mymode ==? "R"
		return ""
	elseif mymode == ""
		return ""
	elseif mymode ==? "n"
		return "N"
	else
		return "  " . mymode . "  "
	endif
endfunction
function! Cream_statusline_modeCOL()
	let mymode = mode()
	if mymode == ""
		return "C"
	else
		return ""
	endif
endfunction
function! Cream_statusline_modeOK()
	let mymode = mode()
	if mymode ==? "i"
		return "I\|"
	elseif mymode ==? "v"
		return "V\|"
	elseif mymode ==? "s"
		return "S\|"
	elseif mymode ==? "R"
		return "R\|"
	else
		return "\|"
	endif
endfunction

function! Cream_statusline_bufsize()
	let bufsize = line2byte(line("$") + 1)
	" add commas
	let remain = bufsize
	let bufsize = ""
	while strlen(remain) > 3
		let bufsize = "," . strpart(remain, strlen(remain) - 3) . bufsize
		let remain = strpart(remain, 0, strlen(remain) - 3)
	endwhile
	let bufsize = remain . bufsize
	return bufsize
endfunction

function! Cream_statusline_filename()
	let myfilename = expand("%:p:t")
	if myfilename == ""
		let myfilename = "(Untitled)"
	endif
	return myfilename
endfunction

" set statusline
" Notes: 
" * Changing highlighting groups dynamically in the status bar has *far*
"   too much overhead and is too slow. So we:
"   - preset all the highlight groups (elsewhere)
"   - pair two calls to two corresponding ON/OFF functions for *each*
"     evaluation
"   - return a value for the actual condition (displayed)
"   - return empty for reverse (isn't displayed)
" * Size is limited to 50 pieces (begin group, enclosee, close
"   group).
" * Close of a highlighting group (%*) is not necessary.

function! Cream_statusline_diffmode()
	if exists("b:cream_diffmode")
		return " diff"
	else
		return ""
	endif
endfunction


"---------------------------------------------------------------------
" current line highlighting test
"
"function! HiCurLine_InsMode()
"    "if mode() == 'i' && exists("g:CREAM_HIGHLIGHT_CURRENTLINE")
"    if exists("g:CREAM_HIGHLIGHT_CURRENTLINE")
"        "let @/ = '\%' . line('.') . 'l.*'
"        execute "silent! match CurrentLine /\\%" . line('.') . "l/"
"    endif
"    return ''
"endfunction
"function! HiCurLine_InsMode_Toggle()
"    if g:HiCurLine == 1
"        set nohls
"        let g:HiCurLine = 0
"    else
"        let g:HiCurLine = 1
"    endif
"endfunction
"let &statusline = '%{HiCurLine_InsMode()}' . &statusline
"let g:HiCurLine = 0
"---------------------------------------------------------------------

" The string "%N*" ... "%*" correspond to the highlight group "UserN"
set statusline=
    \%1*%{Cream_statusline_path()}
	\%2*%{Cream_statusline_filename()}
	\\ %3*%{Cream_statusline_filestate()}
	\%1*[%{Cream_statusline_fileformat()}:
	\%{Cream_statusline_fileencoding()}:
	\%{Cream_statusline_filetype()}]\ %=
	\%3*%{Cream_statusline_expert()}
	\\ %{Cream_statusline_diffmode()}
	\%1*\|
	\%2*%{Cream_statusline_showON()}
	\%1*%{Cream_statusline_showOFF()}\|
	\%2*%{Cream_statusline_wrapON()}
	\%1*%{Cream_statusline_wrapOFF()}:
	\%2*%{Cream_statusline_autowrapON()}
	\%1*%{Cream_statusline_autowrapOFF()}:
	\%3*%{Cream_statusline_wrap_justifyON()}
	\%1*%{Cream_statusline_wrap_justifyOFF()}:
	\%{Cream_statusline_wrap_width()}\|
	\%2*%{Cream_statusline_autoindentON()}
	\%1*%{Cream_statusline_autoindentOFF()}\|
	\%4*%{Cream_statusline_modeNO()}
	\%3*%{Cream_statusline_modeCOL()}
	\%1*%{Cream_statusline_modeOK()}
	\%{Cream_statusline_bufsize()}b\|
	\%05(%l%),%03(%v%)
	\%2*\ %P


"---------------------------------------------------------------------
" statusline 2 (can handle more objects since only half are returned)

"function! Cream_statusline_set()
"" returns a valid string for the statusline
"
"    let statusline = ""
"
"    let statusline = statusline . '%1*%{Cream_statusline_path()}'
"
"    let statusline = statusline . '%2*%{Cream_statusline_filename()}'
"    let statusline = statusline . '\ %3*%{Cream_statusline_filestate()}'
"    let statusline = statusline . '%1*[%{Cream_statusline_fileformat()}:'
"    let statusline = statusline . '%{Cream_statusline_fileencoding()}:'
"    let statusline = statusline . '%{Cream_statusline_filetype()}]\ %='
"
"    if Cream_statusline_expert() != ""
"        let statusline = statusline . '%3*%{Cream_statusline_expert()}'
"    endif
"    let statusline = statusline . '\ '
"    if Cream_statusline_diffmode() != ""
"        let statusline = statusline . '%3*%{Cream_statusline_diffmode()}'
"    endif
"
"    let statusline = statusline . '%1*\|'
"
"    if Cream_statusline_showON() != ""
"        let statusline = statusline . '%2*%{Cream_statusline_showON()}'
"        let statusline = statusline . '%1*\|'
"    else
"        let statusline = statusline . '%{Cream_statusline_showOFF()}\|'
"    endif
"
"    if Cream_statusline_wrapON() != ""
"        let statusline = statusline . '%2*%{Cream_statusline_wrapON()}'
"        let statusline = statusline . '%1*:'
"    else
"        let statusline = statusline . '%{Cream_statusline_wrapOFF()}:'
"    endif
"
"    if Cream_statusline_autowrapON() != ""
"        let statusline = statusline . '%2*%{Cream_statusline_autowrapON()}'
"        let statusline = statusline . '%1*:'
"    else
"        let statusline = statusline . '%{Cream_statusline_autowrapOFF()}:'
"    endif
"
"    if Cream_statusline_wrap_justifyON() != ""
"        let statusline = statusline . '%3*%{Cream_statusline_wrap_justifyON()}'
"        let statusline = statusline . '%1*:'
"    else
"        let statusline = statusline . '%{Cream_statusline_wrap_justifyOFF()}:'
"    endif
"    
"    let statusline = statusline . '%{Cream_statusline_wrap_width()}\|'
"    
"    if Cream_statusline_autoindentON() != ""
"        let statusline = statusline . '%2*%{Cream_statusline_autoindentON()}'
"        let statusline = statusline . '%1*\|'
"    else
"        let statusline = statusline . '%{Cream_statusline_autoindentOFF()}\|'
"    endif
"
"    if Cream_statusline_modeNO() != ''
"        let statusline = statusline . '%4*%{Cream_statusline_modeNO()}'
"    endif
"    if Cream_statusline_modeCOL() != ''
"        let statusline = statusline . '%3*%{Cream_statusline_modeCOL()}'
"    endif
"    if Cream_statusline_modeOK() != ''
"        let statusline = statusline . '%1*%{Cream_statusline_modeOK()}'
"    endif
"
"    let statusline = statusline . '%1*%{Cream_statusline_bufsize()}b\|'
"    let statusline = statusline . '%05(%l%),%03(%c%)'
"    let statusline = statusline . '%2*\ %P'
"
"    return statusline
"
"endfunction
"execute "set statusline=" . Cream_statusline_set()


"---------------------------------------------------------------------
"" attempt at bottom line statusline with "ruler"
"execute "set rulerformat=%" . winwidth(0) . "(" . 
"    \"%1*%{expand('%:p:h')}/" .
"    \"%2*%{Cream_statusline_filename()}\\ " .
"    \"%3*%{Cream_statusline_filestate()}" .
"    \"%1*\\ [%{Cream_statusline_fileformat()}]\\ %=" .
"    \"%3*%{Cream_statusline_expert()}" .
"    \"%{Cream_statusline_diffmode()}" .
"    \"%1*\\|" .
"    \"%2*%{Cream_statusline_showON()}" .
"    \"%1*%{Cream_statusline_showOFF()}\\|" .
"    \"%2*%{Cream_statusline_wrapON()}" .
"    \"%1*%{Cream_statusline_wrapOFF()}:" .
"    \"%2*%{Cream_statusline_autowrapON()}" .
"    \"%1*%{Cream_statusline_autowrapOFF()}:" .
"    \"%{Cream_statusline_wrap_width()}\\|" .
"    \"%4*%{Cream_statusline_modeNO()}" .
"    \"%3*%{Cream_statusline_modeCOL()}" .
"    \"%1*%{Cream_statusline_modeOK()}\\|" .
"    \"%1*%{Cream_statusline_bufsize()}\\ bytes\\|" .
"    \"%1*%05(%l%),%03(%c%)" .
"    \"%2*\\ %P" .
"    \"%)"
"set ruler
"set statusline=
"set laststatus=0

